# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/internal/internal/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Internal\\Internal\\": "packages/internal/internal/src",
            "Internal\\Internal\\Seeders\\": "packages/internal/internal/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Internal\Internal\Providers\InternalServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Internal'  => Internal\Internal\Facades\Internal::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Internal\\Internal\\Seeders\\InternalTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Internal\Internal\Providers\InternalServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Internal\Internal\Providers\InternalServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Internal\Internal\Providers\InternalServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/internal/{modulename}

**User**

    http://path-to-route-folder/user/internal/{modulename}

**Public**

    http://path-to-route-folder/internals


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/internal/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/internal/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/internal/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/internal/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/internal/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/internal/{modulename}/{slug}
    METHOD: GET