<?php

namespace Internal\Internal\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Internal\Internal\Http\Requests\InternalRequest;
use Internal\Internal\Models\Internal;

/**
 * Admin web controller class.
 */
class InternalWorkflowController extends BaseController
{

    /**
     * Workflow controller function for internal.
     *
     * @param Model   $internal
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(InternalRequest $request, Internal $internal, $step)
    {

        try {

            $internal->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('internal::internal.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/internal/internal/' . $internal->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/internal/internal/' . $internal->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for internal.
     *
     * @param Model   $internal
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Internal $internal, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $internal->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('internal::internal.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('internal::admin.internal.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('internal::admin.internal.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('internal::admin.internal.message', $data)->render();

        }

    }
}
