<?php

namespace Internal\Internal\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Internal\Internal\Models\Internal;

class InternalPolicy
{

    /**
     * Determine if the given user can view the internal.
     *
     * @param UserPolicyInterface $authUser
     * @param Internal $internal
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Internal $internal)
    {
        if ($authUser->canDo('internal.internal.view') && $authUser->isAdmin()) {
            return true;
        }

        return $internal->user_id == user_id() && $internal->user_type == user_type();
    }

    /**
     * Determine if the given user can create a internal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('internal.internal.create');
    }

    /**
     * Determine if the given user can update the given internal.
     *
     * @param UserPolicyInterface $authUser
     * @param Internal $internal
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Internal $internal)
    {
        if ($authUser->canDo('internal.internal.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $internal->user_id == user_id() && $internal->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given internal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Internal $internal)
    {
        return $internal->user_id == user_id() && $internal->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given internal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Internal $internal)
    {
        if ($authUser->canDo('internal.internal.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given internal.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Internal $internal)
    {
        if ($authUser->canDo('internal.internal.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
