<?php

namespace Internal\Internal\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Internal\Internal\Models\Internal;

class InternalAction
{
    /**
     * Perform the complete action.
     *
     * @param Internal $internal
     *
     * @return Internal
     */
    public function complete(Internal $internal)
    {
        try {
            $internal->status = 'complete';
            return $internal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Internal $internal
     *
     * @return Internal
     */public function verify(Internal $internal)
    {
        try {
            $internal->status = 'verify';
            return $internal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Internal $internal
     *
     * @return Internal
     */public function approve(Internal $internal)
    {
        try {
            $internal->status = 'approve';
            return $internal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Internal $internal
     *
     * @return Internal
     */public function publish(Internal $internal)
    {
        try {
            $internal->status = 'publish';
            return $internal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Internal $internal
     *
     * @return Internal
     */
    public function archive(Internal $internal)
    {
        try {
            $internal->status = 'archive';
            return $internal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Internal $internal
     *
     * @return Internal
     */
    public function unpublish(Internal $internal)
    {
        try {
            $internal->status = 'unpublish';
            return $internal->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
