<?php

namespace Internal\Internal\Workflow;

use Internal\Internal\Models\Internal;
use Validator;

class InternalValidator
{

    /**
     * Determine if the given internal is valid for complete status.
     *
     * @param Internal $internal
     *
     * @return bool / Validator
     */
    public function complete(Internal $internal)
    {
        return Validator::make($internal->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given internal is valid for verify status.
     *
     * @param Internal $internal
     *
     * @return bool / Validator
     */
    public function verify(Internal $internal)
    {
        return Validator::make($internal->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given internal is valid for approve status.
     *
     * @param Internal $internal
     *
     * @return bool / Validator
     */
    public function approve(Internal $internal)
    {
        return Validator::make($internal->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given internal is valid for publish status.
     *
     * @param Internal $internal
     *
     * @return bool / Validator
     */
    public function publish(Internal $internal)
    {
        return Validator::make($internal->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given internal is valid for archive status.
     *
     * @param Internal $internal
     *
     * @return bool / Validator
     */
    public function archive(Internal $internal)
    {
        return Validator::make($internal->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given internal is valid for unpublish status.
     *
     * @param Internal $internal
     *
     * @return bool / Validator
     */
    public function unpublish(Internal $internal)
    {
        return Validator::make($internal->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
